@@ -69,7 +69,7 @@ function _wp_menu_output( $menu, $submenu, $submenu_as_parent = true ) {
 	global $self, $parent_file, $submenu_file, $plugin_page, $typenow;
 
 	$first = true;
-	// 0 = menu_title, 1 = capability, 2 = menu_slug, 3 = page_title, 4 = classes, 5 = hookname, 6 = icon_url
+	// 0 = menu_title, 1 = capability, 2 = menu_slug, 3 = page_title, 4 = classes, 5 = hookname, 6 = icon_url.
 	foreach ( $menu as $key => $item ) {
 		$admin_is_parent = false;
 		$class           = array();
@@ -108,7 +108,8 @@ function _wp_menu_output( $menu, $submenu, $submenu_as_parent = true ) {
 
 		$class     = $class ? ' class="' . join( ' ', $class ) . '"' : '';
 		$id        = ! empty( $item[5] ) ? ' id="' . preg_replace( '|[^a-zA-Z0-9_:.]|', '-', $item[5] ) . '"' : '';
-		$img       = $img_style = '';
+		$img       = '';
+		$img_style = '';
 		$img_class = ' dashicons-before';
 
 		if ( false !== strpos( $class, 'wp-menu-separator' ) ) {
@@ -152,7 +153,8 @@ function _wp_menu_output( $menu, $submenu, $submenu_as_parent = true ) {
 			$submenu_items = array_values( $submenu_items );  // Re-index.
 			$menu_hook     = get_plugin_page_hook( $submenu_items[0][2], $item[2] );
 			$menu_file     = $submenu_items[0][2];
-			if ( false !== ( $pos = strpos( $menu_file, '?' ) ) ) {
+			$pos           = strpos( $menu_file, '?' );
+			if ( false !== $pos ) {
 				$menu_file = substr( $menu_file, 0, $pos );
 			}
 			if ( ! empty( $menu_hook ) || ( ( 'index.php' != $submenu_items[0][2] ) && file_exists( WP_PLUGIN_DIR . "/$menu_file" ) && ! file_exists( ABSPATH . "/wp-admin/$menu_file" ) ) ) {
@@ -164,7 +166,8 @@ function _wp_menu_output( $menu, $submenu, $submenu_as_parent = true ) {
 		} elseif ( ! empty( $item[2] ) && current_user_can( $item[1] ) ) {
 			$menu_hook = get_plugin_page_hook( $item[2], 'admin.php' );
 			$menu_file = $item[2];
-			if ( false !== ( $pos = strpos( $menu_file, '?' ) ) ) {
+			$pos       = strpos( $menu_file, '?' );
+			if ( false !== $pos ) {
 				$menu_file = substr( $menu_file, 0, $pos );
 			}
 			if ( ! empty( $menu_hook ) || ( ( 'index.php' != $item[2] ) && file_exists( WP_PLUGIN_DIR . "/$menu_file" ) && ! file_exists( ABSPATH . "/wp-admin/$menu_file" ) ) ) {
@@ -181,7 +184,7 @@ function _wp_menu_output( $menu, $submenu, $submenu_as_parent = true ) {
 
 			$first = true;
 
-			// 0 = menu_title, 1 = capability, 2 = menu_slug, 3 = page_title, 4 = classes
+			// 0 = menu_title, 1 = capability, 2 = menu_slug, 3 = page_title, 4 = classes.
 			foreach ( $submenu_items as $sub_key => $sub_item ) {
 				if ( ! current_user_can( $sub_item[1] ) ) {
 					continue;
@@ -196,7 +199,8 @@ function _wp_menu_output( $menu, $submenu, $submenu_as_parent = true ) {
 
 				$menu_file = $item[2];
 
-				if ( false !== ( $pos = strpos( $menu_file, '?' ) ) ) {
+				$pos = strpos( $menu_file, '?' );
+				if ( false !== $pos ) {
 					$menu_file = substr( $menu_file, 0, $pos );
 				}
 
@@ -226,14 +230,15 @@ function _wp_menu_output( $menu, $submenu, $submenu_as_parent = true ) {
 
 				$menu_hook = get_plugin_page_hook( $sub_item[2], $item[2] );
 				$sub_file  = $sub_item[2];
-				if ( false !== ( $pos = strpos( $sub_file, '?' ) ) ) {
+				$pos       = strpos( $sub_file, '?' );
+				if ( false !== $pos ) {
 					$sub_file = substr( $sub_file, 0, $pos );
 				}
 
 				$title = wptexturize( $sub_item[0] );
 
 				if ( ! empty( $menu_hook ) || ( ( 'index.php' != $sub_item[2] ) && file_exists( WP_PLUGIN_DIR . "/$sub_file" ) && ! file_exists( ABSPATH . "/wp-admin/$sub_file" ) ) ) {
-					// If admin.php is the current page or if the parent exists as a file in the plugins or admin dir
+					// If admin.php is the current page or if the parent exists as a file in the plugins or admin directory.
 					if ( ( ! $admin_is_parent && file_exists( WP_PLUGIN_DIR . "/$menu_file" ) && ! is_dir( WP_PLUGIN_DIR . "/{$item[2]}" ) ) || file_exists( $menu_file ) ) {
 						$sub_item_url = add_query_arg( array( 'page' => $sub_item[2] ), $item[2] );
 					} else {
