@@ -7,10 +7,10 @@
  */
 
 /** WordPress Administration Bootstrap */
-require_once( dirname( __FILE__ ) . '/admin.php' );
+require_once __DIR__ . '/admin.php';
 
 /** WordPress Administration Widgets API */
-require_once( ABSPATH . 'wp-admin/includes/widgets.php' );
+require_once ABSPATH . 'wp-admin/includes/widgets.php';
 
 if ( ! current_user_can( 'edit_theme_options' ) ) {
 	wp_die(
@@ -24,11 +24,11 @@ $widgets_access = get_user_setting( 'widgets_access' );
 if ( isset( $_GET['widgets-access'] ) ) {
 	check_admin_referer( 'widgets-access' );
 
-	$widgets_access = 'on' == $_GET['widgets-access'] ? 'on' : 'off';
+	$widgets_access = 'on' === $_GET['widgets-access'] ? 'on' : 'off';
 	set_user_setting( 'widgets_access', $widgets_access );
 }
 
-if ( 'on' == $widgets_access ) {
+if ( 'on' === $widgets_access ) {
 	add_filter( 'admin_body_class', 'wp_widgets_access_body_class' );
 } else {
 	wp_enqueue_script( 'admin-widgets' );
@@ -88,7 +88,7 @@ if ( ! current_theme_supports( 'widgets' ) ) {
 	wp_die( __( 'The theme you are currently using isn&#8217;t widget-aware, meaning that it has no sidebars that you are able to change. For information on making your theme widget-aware, please <a href="https://developer.wordpress.org/themes/functionality/widgets/">follow these instructions</a>.' ) );
 }
 
-// These are the widgets grouped by sidebar
+// These are the widgets grouped by sidebar.
 $sidebars_widgets = wp_get_sidebars_widgets();
 
 if ( empty( $sidebars_widgets ) ) {
@@ -96,12 +96,12 @@ if ( empty( $sidebars_widgets ) ) {
 }
 
 foreach ( $sidebars_widgets as $sidebar_id => $widgets ) {
-	if ( 'wp_inactive_widgets' == $sidebar_id ) {
+	if ( 'wp_inactive_widgets' === $sidebar_id ) {
 		continue;
 	}
 
 	if ( ! is_registered_sidebar( $sidebar_id ) ) {
-		if ( ! empty( $widgets ) ) { // register the inactive_widgets area as sidebar
+		if ( ! empty( $widgets ) ) { // Register the inactive_widgets area as sidebar.
 			register_sidebar(
 				array(
 					'name'          => __( 'Inactive Sidebar (not used)' ),
@@ -120,7 +120,7 @@ foreach ( $sidebars_widgets as $sidebar_id => $widgets ) {
 	}
 }
 
-// register the inactive_widgets area as sidebar
+// Register the inactive_widgets area as sidebar.
 register_sidebar(
 	array(
 		'name'          => __( 'Inactive Widgets' ),
@@ -136,7 +136,7 @@ register_sidebar(
 
 retrieve_widgets();
 
-// We're saving a widget without js
+// We're saving a widget without JS.
 if ( isset( $_POST['savewidget'] ) || isset( $_POST['removewidget'] ) ) {
 	$widget_id = $_POST['widget-id'];
 	check_admin_referer( "save-delete-widget-$widget_id" );
@@ -188,7 +188,7 @@ if ( isset( $_POST['savewidget'] ) || isset( $_POST['removewidget'] ) ) {
 	$_POST['widget-id'] = $sidebar;
 
 	foreach ( (array) $wp_registered_widget_updates as $name => $control ) {
-		if ( $name != $id_base || ! is_callable( $control['callback'] ) ) {
+		if ( $name !== $id_base || ! is_callable( $control['callback'] ) ) {
 			continue;
 		}
 
@@ -216,7 +216,7 @@ if ( isset( $_POST['savewidget'] ) || isset( $_POST['removewidget'] ) ) {
 	exit;
 }
 
-// Remove inactive widgets without js
+// Remove inactive widgets without JS.
 if ( isset( $_POST['removeinactivewidgets'] ) ) {
 	check_admin_referer( 'remove-inactive-widgets', '_wpnonce_remove_inactive_widgets' );
 
@@ -238,17 +238,17 @@ if ( isset( $_POST['removeinactivewidgets'] ) ) {
 	exit;
 }
 
-// Output the widget form without js
+// Output the widget form without JS.
 if ( isset( $_GET['editwidget'] ) && $_GET['editwidget'] ) {
 	$widget_id = $_GET['editwidget'];
 
 	if ( isset( $_GET['addnew'] ) ) {
-		// Default to the first sidebar
+		// Default to the first sidebar.
 		$keys    = array_keys( $wp_registered_sidebars );
 		$sidebar = reset( $keys );
 
-		if ( isset( $_GET['base'] ) && isset( $_GET['num'] ) ) { // multi-widget
-			// Copy minimal info from an existing instance of this widget to a new instance
+		if ( isset( $_GET['base'] ) && isset( $_GET['num'] ) ) { // Multi-widget.
+			// Copy minimal info from an existing instance of this widget to a new instance.
 			foreach ( $wp_registered_widget_controls as $control ) {
 				if ( $_GET['base'] === $control['id_base'] ) {
 					$control_callback                                = $control['callback'];
@@ -288,7 +288,7 @@ if ( isset( $_GET['editwidget'] ) && $_GET['editwidget'] ) {
 	$width = ' style="width:' . max( $control['width'], 350 ) . 'px"';
 	$key   = isset( $_GET['key'] ) ? (int) $_GET['key'] : 0;
 
-	require_once( ABSPATH . 'wp-admin/admin-header.php' ); ?>
+	require_once ABSPATH . 'wp-admin/admin-header.php'; ?>
 	<div class="wrap">
 	<h1><?php echo esc_html( $title ); ?></h1>
 	<div class="editwidget"<?php echo $width; ?>>
@@ -316,7 +316,7 @@ if ( isset( $_GET['editwidget'] ) && $_GET['editwidget'] ) {
 	<?php
 	foreach ( $wp_registered_sidebars as $sbname => $sbvalue ) {
 		echo "\t\t<tr><td><label><input type='radio' name='sidebar' value='" . esc_attr( $sbname ) . "'" . checked( $sbname, $sidebar, false ) . " /> $sbvalue[name]</label></td><td>";
-		if ( 'wp_inactive_widgets' == $sbname || 'orphaned_widgets' == substr( $sbname, 0, 16 ) ) {
+		if ( 'wp_inactive_widgets' === $sbname || 'orphaned_widgets' === substr( $sbname, 0, 16 ) ) {
 			echo '&nbsp;';
 		} else {
 			if ( ! isset( $sidebars_widgets[ $sbname ] ) || ! is_array( $sidebars_widgets[ $sbname ] ) ) {
@@ -366,7 +366,7 @@ if ( isset( $_GET['editwidget'] ) && $_GET['editwidget'] ) {
 	</div>
 	</div>
 	<?php
-	require_once( ABSPATH . 'wp-admin/admin-footer.php' );
+	require_once ABSPATH . 'wp-admin/admin-footer.php';
 	exit;
 }
 
@@ -379,7 +379,7 @@ $errors = array(
 	__( 'Error in displaying the widget settings form.' ),
 );
 
-require_once( ABSPATH . 'wp-admin/admin-header.php' );
+require_once ABSPATH . 'wp-admin/admin-header.php';
 ?>
 
 <div class="wrap">
@@ -456,13 +456,13 @@ do_action( 'widgets_admin_page' );
 
 $theme_sidebars = array();
 foreach ( $wp_registered_sidebars as $sidebar => $registered_sidebar ) {
-	if ( false !== strpos( $registered_sidebar['class'], 'inactive-sidebar' ) || 'orphaned_widgets' == substr( $sidebar, 0, 16 ) ) {
+	if ( false !== strpos( $registered_sidebar['class'], 'inactive-sidebar' ) || 'orphaned_widgets' === substr( $sidebar, 0, 16 ) ) {
 		$wrap_class = 'widgets-holder-wrap';
 		if ( ! empty( $registered_sidebar['class'] ) ) {
 			$wrap_class .= ' ' . $registered_sidebar['class'];
 		}
 
-		$is_inactive_widgets = 'wp_inactive_widgets' == $registered_sidebar['id'];
+		$is_inactive_widgets = 'wp_inactive_widgets' === $registered_sidebar['id'];
 		?>
 		<div class="<?php echo esc_attr( $wrap_class ); ?>">
 			<div class="widget-holder inactive">
@@ -510,7 +510,7 @@ $single_sidebar_class = '';
 $sidebars_count       = count( $theme_sidebars );
 
 if ( $sidebars_count > 1 ) {
-	$split = ceil( $sidebars_count / 2 );
+	$split = (int) ceil( $sidebars_count / 2 );
 } else {
 	$single_sidebar_class = ' single-sidebar';
 }
@@ -531,7 +531,7 @@ foreach ( $theme_sidebars as $sidebar => $registered_sidebar ) {
 		$wrap_class .= ' closed';
 	}
 
-	if ( $split && $i == $split ) {
+	if ( $split && $i === $split ) {
 		?>
 		</div><div class="sidebars-column-2">
 		<?php
@@ -539,7 +539,10 @@ foreach ( $theme_sidebars as $sidebar => $registered_sidebar ) {
 
 	?>
 	<div class="<?php echo esc_attr( $wrap_class ); ?>">
-		<?php wp_list_widget_controls( $sidebar, $registered_sidebar['name'] ); // Show the control forms for each of the widgets in this sidebar ?>
+		<?php
+		// Show the control forms for each of the widgets in this sidebar.
+		wp_list_widget_controls( $sidebar, $registered_sidebar['name'] );
+		?>
 	</div>
 	<?php
 
@@ -572,4 +575,4 @@ foreach ( $theme_sidebars as $sidebar => $registered_sidebar ) {
  * @since 2.2.0
  */
 do_action( 'sidebar_admin_page' );
-require_once( ABSPATH . 'wp-admin/admin-footer.php' );
+require_once ABSPATH . 'wp-admin/admin-footer.php';
